@@ -45,14 +45,14 @@ const struct ltc_hash_descriptor whirlpool_desc =
 
 /* shortcut macro to perform three functions at once */
 #define theta_pi_gamma(a, i)             \
-    SB0(GB(a, i-0, 7)) ^                 \
+   (SB0(GB(a, i-0, 7)) ^                 \
     SB1(GB(a, i-1, 6)) ^                 \
     SB2(GB(a, i-2, 5)) ^                 \
     SB3(GB(a, i-3, 4)) ^                 \
     SB4(GB(a, i-4, 3)) ^                 \
     SB5(GB(a, i-5, 2)) ^                 \
     SB6(GB(a, i-6, 1)) ^                 \
-    SB7(GB(a, i-7, 0))
+    SB7(GB(a, i-7, 0)))
 
 #ifdef LTC_CLEAN_STACK
 static int _whirlpool_compress(hash_state *md, unsigned char *buf)
