@@ -34,9 +34,6 @@
 #ifndef XCLOCK
 #define XCLOCK   clock
 #endif
-#ifndef XCLOCKS_PER_SEC
-#define XCLOCKS_PER_SEC CLOCKS_PER_SEC
-#endif
 
 #ifndef XQSORT
 #define XQSORT qsort
@@ -106,11 +103,13 @@
 
 /* The minimal set of functionality to run the tests */
 #ifdef LTC_MINIMAL
+   #define LTC_RIJNDAEL
    #define LTC_SHA256
+   #define LTC_YARROW
    #define LTC_CTR_MODE
+
    #define LTC_RNG_MAKE_PRNG
    #define LTC_RNG_GET_BYTES
-   #define LTC_YARROW
    #define LTC_DEVRANDOM
    #define LTC_TRY_URANDOM_FIRST
 
@@ -151,11 +150,11 @@
 /* TomsFastMath */
 /* #define TFM_DESC */
 
-#endif /* LTC_NO_MATH */
-
 /* GNU Multiple Precision Arithmetic Library */
 /* #define GMP_DESC */
 
+#endif /* LTC_NO_MATH */
+
 /* ---> Symmetric Block Ciphers <--- */
 #ifndef LTC_NO_CIPHERS
 
@@ -282,13 +281,6 @@
 
 /* Yarrow */
 #define LTC_YARROW
-/* which descriptor of AES to use?  */
-/* 0 = rijndael_enc 1 = aes_enc, 2 = rijndael [full], 3 = aes [full] */
-#ifdef ENCRYPT_ONLY
-  #define LTC_YARROW_AES 0
-#else
-  #define LTC_YARROW_AES 2
-#endif
 
 /* a PRNG that simply reads from an available system source */
 #define LTC_SPRNG
@@ -314,6 +306,18 @@
 
 #endif /* LTC_NO_PRNGS */
 
+#ifdef LTC_YARROW
+
+/* which descriptor of AES to use?  */
+/* 0 = rijndael_enc 1 = aes_enc, 2 = rijndael [full], 3 = aes [full] */
+#ifdef ENCRYPT_ONLY
+  #define LTC_YARROW_AES 0
+#else
+  #define LTC_YARROW_AES 2
+#endif
+
+#endif
+
 #ifdef LTC_FORTUNA
 
 #ifndef LTC_FORTUNA_WD
